function varargout = Fourth(varargin)
% FOURTH M-file for Fourth.fig
%      FOURTH, by itself, creates a new FOURTH or raises the existing
%      singleton*.
%
%      H = FOURTH returns the handle to a new FOURTH or the handle to
%      the existing singleton*.
%
%      FOURTH('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in FOURTH.M with the given input arguments.
%
%      FOURTH('Property','Value',...) creates a new FOURTH or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Fourth_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Fourth_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Fourth

% Last Modified by GUIDE v2.5 01-Dec-2003 11:52:36

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Fourth_OpeningFcn, ...
                   'gui_OutputFcn',  @Fourth_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Fourth is made visible.
function Fourth_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Fourth (see VARARGIN)
handles.mydata=0;

% Choose default command line output for Fourth
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Fourth wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Fourth_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;





% --- Executes during object creation, after setting all properties.
function listbox1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to listbox1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in listbox1.
function listbox1_Callback(hObject, eventdata, handles)
% hObject    handle to listbox1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns listbox1 contents as cell array
%        contents{get(hObject,'Value')} returns selected item from listbox1

contents = get(hObject,'String'); 
val=get(hObject,'Value'); 

switch(val)
    
    case 2
         I=imread('fig_1.jpg');
         axes(handles.axes1)
         image(I);
         handles.mydata=I
         guidata(hObject, handles)
    case 3
         I=imread('fig_2.jpg');
         axes(handles.axes1)
         image(I);
         handles.mydata=I
         guidata(hObject, handles)
       case 4
         I=imread('fig_3.jpg');
         axes(handles.axes1)
         image(I);
         handles.mydata=I
         guidata(hObject, handles)
    case 5
         I=imread('fig_4.jpg');
         axes(handles.axes1)
         image(I);
         handles.mydata=I
         guidata(hObject, handles)
    case 6
         I=imread('fig_5.jpg');
         axes(handles.axes1)
         image(I);
         handles.mydata=I
         guidata(hObject, handles)
    case 7
         I=imread('fig_6.jpg');
         axes(handles.axes1)
         image(I);
         handles.mydata=I
         guidata(hObject, handles)

     
     end


% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

fig = gcf;
   quit_reply = questdlg('Really quit this lame example?');
   if strcmp(quit_reply,'Yes')
      close(fig);

  end

% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
I=handles.mydata;
II     = im2double(I);
[row, column, height] = size(II);

%%%%% binarize by thresholding, with threshold equal  to the pixel value avg %%%%%%
ave_pixel = zeros(1,3);
sum       = zeros(1,3);
for i = 1:height
    for j = 1:row
        for k = 1:column
            sum(1,i)       = sum(1,i) + II(j,k,i);
            ave_pixel(1,i) = sum(1,i)/(row*column);%%%%%%%%%%%finding the pixel average%%%%%%%%%
        end
    end
end

%assigning the value 1 if the average value is less than the image pixel value
%else value 0 is assigned
for i = 1:height
    for j = 1:row
        for k = 1:column
            if II(j,k,i) > ave_pixel(1,i)
                Bi_th(j,k,i) = 1;
            else
                Bi_th(j,k,i) = 0;
            end
        end
    end
end

% imshow(II);
% figure
axes(handles.axes2)
imshow(Bi_th);
